SystemOrganization addCategory: #'Zodiac-Debug'!

TestCase subclass: #ZdcDebugTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zodiac-Debug'!

!ZdcDebugTests commentStamp: '<historical>' prior: 0!
I am ZdcDebugTests, a special test suite for low level Zodiac debugging.!

!ZdcDebugTests methodsFor: 'running' stamp: 'SvenVanCaekenberghe 7/11/2012 21:11'!
setUp
	ZdcObjectLog default
		clear.
	ZnNetworkingUtils default
		secureSocketStreamClass: ZdcDebugSecureSocketStream! !

!ZdcDebugTests methodsFor: 'running' stamp: 'SvenVanCaekenberghe 7/11/2012 21:08'!
tearDown
	ZnNetworkingUtils default
		secureSocketStreamClass: nil! !

!ZdcDebugTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 7/12/2012 11:12'!
testGetPharoVersion
	| client lastBuildVersion |
	lastBuildVersion := (client := ZnClient new)
		beOneShot;
		get: 'https://ci.lille.inria.fr/pharo/job/Pharo-2.0/lastSuccessfulBuild/api/xml?xpath=/*/description/text()'.
	self assert: client isSuccess.
	self assert: client response contentType equals: ZnMimeType textPlain.
	self assert: client response contentLength > 0.
	self assert: lastBuildVersion notNil.
	self assert: lastBuildVersion isString.
	self assert: lastBuildVersion size > 0
	! !

!ZdcDebugTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 7/11/2012 21:07'!
testSecureSocketStreamClass
	self
		assert: ZnNetworkingUtils default secureSocketStreamClass 
		equals: ZdcDebugSecureSocketStream! !

!ZdcDebugTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 7/11/2012 21:04'!
testSimple
	| client |
	(client := ZnClient new)
		https;
		host: 's3-eu-west-1.amazonaws.com';
		addPath: 'public-stfx-eu';
		addPath: ('test-', 2050 asString, '.txt');
		get;
		close.
	self assert: client isSuccess.
	self assert: client response contentType equals: ZnMimeType textPlain.
	self assert: client response contentLength equals: 2050.
	self 
		assert: client contents 
		equals: (ZnHTTPSTests generateTestData: 2050)! !

ZdcPluginSSLSession subclass: #ZdcDebugPluginSSLSession
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zodiac-Debug'!

!ZdcDebugPluginSSLSession commentStamp: '<historical>' prior: 0!
I am ZdcDebugPluginSSLSession, an instrumented ZdcPluginSSLSession.!

!ZdcDebugPluginSSLSession methodsFor: 'operations' stamp: 'SvenVanCaekenberghe 7/11/2012 23:47'!
accept: srcBuf from: start to: stop into: dstBuf
	"Start or continue the server handshake using the given input token"

	| result |
	self before: 'SSL Plugin Accept' source: srcBuf from: start to: stop destination: dstBuf. 
	result := super accept: srcBuf from: start to: stop into: dstBuf.
	self after: 'SSL Plugin Accepted' result: result destination: dstBuf.
	^ result! !

!ZdcDebugPluginSSLSession methodsFor: 'private' stamp: 'SvenVanCaekenberghe 7/11/2012 21:11'!
after: operation result: result destination: destination
	ZdcObjectLog default
		add: ((ZdcSSLSessionOperationStop message: operation)
				result: result;
				destination: destination copy;
				yourself)! !

!ZdcDebugPluginSSLSession methodsFor: 'private' stamp: 'SvenVanCaekenberghe 7/11/2012 20:57'!
before: operation source: source from: start to: stop destination: destination
	ZdcObjectLog default
		add: ((ZdcSSLSessionOperationStart message: operation)
				source: source copy;
				start: start;
				stop: stop;
				destination: destination copy;
				yourself)! !

!ZdcDebugPluginSSLSession methodsFor: 'operations' stamp: 'SvenVanCaekenberghe 7/11/2012 23:47'!
connect: srcBuf from: start to: stop into: dstBuf
	"Start or continue the client handshake using the given input token"

	| result |
	self before: 'SSL Plugin Connect' source: srcBuf from: start to: stop destination: dstBuf. 
	result := super connect: srcBuf from: start to: stop into: dstBuf.
	self after: 'SSL Plugin Connected' result: result destination: dstBuf.
	^ result! !

!ZdcDebugPluginSSLSession methodsFor: 'operations' stamp: 'SvenVanCaekenberghe 7/11/2012 23:47'!
decrypt: srcBuf from: start to: stop into: dstBuf
	"Decrypt the input in srcBuf from start to stop into dstBuf."

	| result |
	self before: 'SSL Plugin Decrypt' source: srcBuf from: start to: stop destination: dstBuf. 
	result := super decrypt: srcBuf from: start to: stop into: dstBuf.
	self after: 'SSL Plugin Decrypted' result: result destination: dstBuf.
	^ result! !

!ZdcDebugPluginSSLSession methodsFor: 'operations' stamp: 'SvenVanCaekenberghe 7/11/2012 23:47'!
encrypt: srcBuf from: start to: stop into: dstBuf
	"Encrypt the input in srcBuf from start to stop into dstBuf."

	| result |
	self before: 'SSL Plugin Encrypt' source: srcBuf from: start to: stop destination: dstBuf. 
	result := super encrypt: srcBuf from: start to: stop into: dstBuf.
	self after: 'SSL Plugin Encrypted' result: result destination: dstBuf.
	^ result! !

ZdcSecureSocketStream subclass: #ZdcDebugSecureSocketStream
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zodiac-Debug'!

!ZdcDebugSecureSocketStream commentStamp: '<historical>' prior: 0!
I am ZdcDebugSecureSocketStream, an instrumented ZdcSecureSocketStream.!

!ZdcDebugSecureSocketStream methodsFor: 'ssl' stamp: 'SvenVanCaekenberghe 7/11/2012 23:46'!
accept
	self logMessage: 'SSL Stream Accept'.
	super accept.
	self logMessage: 'SSL Stream Accepted'! !

!ZdcDebugSecureSocketStream methodsFor: 'ssl' stamp: 'SvenVanCaekenberghe 7/11/2012 23:49'!
connect
	self logMessage: 'SSL Stream Connect'.
	super connect.
	self logMessage: 'SSL Stream Connected'! !

!ZdcDebugSecureSocketStream methodsFor: 'private in' stamp: 'SvenVanCaekenberghe 7/12/2012 15:30'!
fillReadBuffer
	self logMessage: 'SSL Stream Fill Read Buffer'.
	super fillReadBuffer.
	self logMessage: 'SSL Stream Filled Read Buffer'! !

!ZdcDebugSecureSocketStream methodsFor: 'private out' stamp: 'SvenVanCaekenberghe 7/12/2012 15:36'!
flushWriteBuffer
	self logMessage: 'SSL Stream Flush Write Buffer'.
	super flushWriteBuffer.
	self logMessage: 'SSL Stream Flushed Write Buffer'! !

!ZdcDebugSecureSocketStream methodsFor: 'private' stamp: 'SvenVanCaekenberghe 7/12/2012 14:06'!
logMessage: message
	ZdcObjectLog default
		add: (ZdcLogEvent message: message)! !

!ZdcDebugSecureSocketStream methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 7/11/2012 21:07'!
sslSessionClass
	^ ZdcDebugPluginSSLSession ! !

Object subclass: #ZdcLogEvent
	instanceVariableNames: 'timestamp pid message'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zodiac-Debug'!

!ZdcLogEvent commentStamp: '<historical>' prior: 0!
I am ZdcLogEvent, a superclass for log events.
!

!ZdcLogEvent class methodsFor: 'instance creation' stamp: 'SvenVanCaekenberghe 7/11/2012 20:41'!
message: string
	^ self new
		message: string;
		yourself! !

!ZdcLogEvent methodsFor: 'initialize-release' stamp: 'SvenVanCaekenberghe 7/11/2012 19:35'!
initialize 
	super initialize.
	timestamp := DateAndTime now asUTC.
	pid := ZnUtils currentProcessID! !

!ZdcLogEvent methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 7/11/2012 19:33'!
message
	^ message! !

!ZdcLogEvent methodsFor: 'initialize-release' stamp: 'SvenVanCaekenberghe 7/11/2012 19:33'!
message: anObject
	message := anObject! !

!ZdcLogEvent methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 7/11/2012 19:33'!
pid
	^ pid! !

!ZdcLogEvent methodsFor: 'initialize-release' stamp: 'SvenVanCaekenberghe 7/11/2012 19:33'!
pid: anObject
	pid := anObject! !

!ZdcLogEvent methodsFor: 'printing' stamp: 'SvenVanCaekenberghe 7/11/2012 23:59'!
printFieldsOn: stream
	timestamp printYMDOn: stream.
	stream nextPut: $T.
	timestamp printHMSOn: stream.
	stream nextPut: $. .
	timestamp nanoSecond printOn: stream base: 10 length: 9 padded: true.
	stream space; nextPut: $$; print: pid.
	message ifNotNil: [
		stream
			space;
			nextPutAll: message ]! !

!ZdcLogEvent methodsFor: 'printing' stamp: 'SvenVanCaekenberghe 7/11/2012 19:37'!
printO: stream
	super printOn: stream.
	stream nextPut: $(.
	self printFieldsOn: stream.
	stream nextPut: $)! !

!ZdcLogEvent methodsFor: 'printing' stamp: 'SvenVanCaekenberghe 7/11/2012 19:37'!
printOn: stream
	super printOn: stream.
	stream nextPut: $(.
	self printFieldsOn: stream.
	stream nextPut: $)! !

!ZdcLogEvent methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 7/11/2012 19:33'!
timestamp
	^ timestamp! !

!ZdcLogEvent methodsFor: 'initialize-release' stamp: 'SvenVanCaekenberghe 7/11/2012 19:33'!
timestamp: anObject
	timestamp := anObject! !

ZdcLogEvent subclass: #ZdcSSLSessionOperationStart
	instanceVariableNames: 'source start stop destination'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zodiac-Debug'!

!ZdcSSLSessionOperationStart commentStamp: '<historical>' prior: 0!
I am ZdcSSLSessionOperationStart, recording the situation before an SSL session opertion.!

!ZdcSSLSessionOperationStart methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 7/11/2012 20:52'!
destination
	^ destination! !

!ZdcSSLSessionOperationStart methodsFor: 'initialize-release' stamp: 'SvenVanCaekenberghe 7/11/2012 20:52'!
destination: anObject
	destination := anObject! !

!ZdcSSLSessionOperationStart methodsFor: 'printing' stamp: 'SvenVanCaekenberghe 7/12/2012 14:08'!
printFieldsOn: stream
	super printFieldsOn: stream.
	stream space; print: start; space; print: stop! !

!ZdcSSLSessionOperationStart methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 7/11/2012 20:52'!
source
	^ source! !

!ZdcSSLSessionOperationStart methodsFor: 'initialize-release' stamp: 'SvenVanCaekenberghe 7/11/2012 20:52'!
source: anObject
	source := anObject! !

!ZdcSSLSessionOperationStart methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 7/11/2012 20:52'!
start
	^ start! !

!ZdcSSLSessionOperationStart methodsFor: 'initialize-release' stamp: 'SvenVanCaekenberghe 7/11/2012 20:52'!
start: anObject
	start := anObject! !

!ZdcSSLSessionOperationStart methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 7/11/2012 20:52'!
stop
	^ stop! !

!ZdcSSLSessionOperationStart methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 7/11/2012 20:52'!
stop: anObject
	stop := anObject! !

ZdcLogEvent subclass: #ZdcSSLSessionOperationStop
	instanceVariableNames: 'result destination'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zodiac-Debug'!

!ZdcSSLSessionOperationStop commentStamp: '<historical>' prior: 0!
I am ZdcSSLSessionOperationStop, recording the situation after an SSL session operation.!

!ZdcSSLSessionOperationStop methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 7/11/2012 20:52'!
destination
	^ destination! !

!ZdcSSLSessionOperationStop methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 7/11/2012 20:52'!
destination: anObject
	destination := anObject! !

!ZdcSSLSessionOperationStop methodsFor: 'printing' stamp: 'SvenVanCaekenberghe 7/12/2012 14:09'!
printFieldsOn: stream
	super printFieldsOn: stream.
	stream nextPutAll: ' -> '; print: result! !

!ZdcSSLSessionOperationStop methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 7/11/2012 20:52'!
result
	^ result! !

!ZdcSSLSessionOperationStop methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 7/11/2012 20:52'!
result: anObject
	result := anObject! !

Object subclass: #ZdcObjectLog
	instanceVariableNames: 'log'
	classVariableNames: 'Default'
	poolDictionaries: ''
	category: 'Zodiac-Debug'!

!ZdcObjectLog commentStamp: '<historical>' prior: 0!
I am ZdcObjectLog, I hold an OrderedCollection of log events.
!

!ZdcObjectLog class methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 7/11/2012 19:42'!
default
	^ Default ifNil: [ Default := self new ]! !

!ZdcObjectLog methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 7/11/2012 19:30'!
add: eventObject
	log add: eventObject ! !

!ZdcObjectLog methodsFor: 'initialize-release' stamp: 'SvenVanCaekenberghe 7/11/2012 19:41'!
clear
	log removeAll ! !

!ZdcObjectLog methodsFor: 'initialize-release' stamp: 'SvenVanCaekenberghe 7/11/2012 19:29'!
initialize 
	super initialize.
	log := OrderedCollection new! !

!ZdcObjectLog methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 7/11/2012 21:15'!
log
	^ log! !
